==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/pr/vpr09Config.h <==
/*!================================================================

  module:       vpr09Config.h

 -------------------------------------------------------------------

  responsible:  BurkhardD

  special area: Handling Configuration (ini) file entrys


  description : Handling of '.ini' files on UNIX and registry on NT.

     This module based on Registry for UNIX written by Joerg Mensing.
     It appends ven09.c functionalty to do the same on NT but use there 
     the registry instead of files.

  see also:

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#ifndef __VPR09_CONFIG_H__
#define __VPR09_CONFIG_H__

/*==================================================================*
 *  INCLUDES                                                        *
 *==================================================================*/

#include "hen09.h"

/*==================================================================*
 *  DECLARATIONS                                                    *
 *==================================================================*/

#ifdef __cplusplus
extern "C" {                         /* Assume C declarations for C++ */
#endif  /* __cplusplus */

#define KEY_SAP "SOFTWARE\\SAP"

typedef enum ConfigResult_tpr09 
{ 
  ERR_OK_epr09, 
  ERR_NOT_OK_epr09, 
  ERR_NO_MORE_DATA_epr09
} ConfigResult_tpr09;

#ifndef WIN32
typedef then09_ConfigHandle ConfigHandle_tpr09;
#else
typedef struct ConfigHandleStruct_tpr09 {
  HKEY hkResult;
  DWORD Index;
} ConfigHandleStruct_tpr09; 
typedef ConfigHandleStruct_tpr09 *ConfigHandle_tpr09;
#endif

/*==================================================================*
 *  EXTERNAL PROTOTYPES                                             *
 *==================================================================*/

/*!
  Function:     pr09ConfigPutString ()

  description:  Writes or updates a Config Entry
  
   Inserts or replaces a string into the registry name 'szFile'
   to a position descripted by 'szSection'-name and 'szEntry'-name.
 
  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    szEntry [in] Given key of 'key=value' entry
    szString [in] Given value of 'key=value' entry
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigPutString (const char *szFile, 
		     const char *szSection,
		     const char *szEntry, 
		     const char *szString,
		     tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigPutStringEx ()

  description:  Writes or updates a Config Entry for use with key LdrDiagEnabled.
  
 */

ConfigResult_tpr09 pr09ConfigPutStringEx (const char *szFile, 
		     const char *szSection,
		     const char *szEntry, 
		     const char *szString,
		     tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigGetString ()

  description:  Reads the Stringvalue from the Config Entry
  
    Gives back a string from registry 'szFile' from the position descripted by
    'szSection' and 'szEntry'. It fails if either the file, the section or the
    entry does not exist.

  arguments:
    szFile [in] Name of registry file
    szSection [in] Given section to read from
    szEntry [in] Given key of 'key=value' entry
    szString [out] Place to store the value of 'key=value' entry
    MaxStringLen [in] Maximum value buffer size
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigGetString (const char * szFile, 
		     const char * szSection, 
		     const char * szEntry, 
		     char * szString, 
		     const int  MaxStringLen, 
		     tsp00_ErrText ErrText);

ConfigResult_tpr09 pr09ConfigGetStringEx (const char * szFile, 
		     const char * szSection, 
		     const char * szEntry, 
		     char * szString, 
		     const int  MaxStringLen, 
		     tsp00_ErrText ErrText);


/*!
  Function:     pr09ConfigRemoveEntry ()

  description:  Remove a Configentry from Registry
                
    Removes the entry specified by 'szSection' and 'szEntry' from config file 

  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    szEntry [in] Given key of 'key=value' entry
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */

ConfigResult_tpr09 pr09ConfigRemoveEntry (const char * szFile, 
		       const char * szSection,  
		       const char * szEntry,
		       tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigOpenSection ()

  description:  Open the registry 'szSection' for enumeration of the entrys
                
    Open the registery and position to the first entry of the given section.
    It is expected that a loop over 'pr09ConfigNextEntry()' is used to retrieve the
    entries.

    You must call pr09ConfigCloseSection after last usage of pr09ConfigNextEntry in all
    cases.
  
  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    ErrText [out] Place for descriptive error message

  return value:
    <UL>
        handle  used in subsequent pr09ConfigNextEntry calls or NULL if an error occured
    </UL>
 */
ConfigHandle_tpr09 pr09ConfigOpenSection (const char *szFile, 
			    const char *szSection,
			    tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigNextEntry ()

  description:  Reads next entry from registry opened by pr09ConfigOpenSection ()
                
   Reads next 'szEntry' and 'szString' from section of config file opened by 
   pr09ConfigOpenSection (). If caller like, he can pass NULL pointer, which make
   it possible ie. just to count the entries of a section...

   Gives back 'ERR_NO_MORE_DATA_pr09' in return on end of section or end of file.
  
  arguments:
    hConfig [in] Handle of registry file
    szEntry [out] Place to store to key of 'key=value' entry (NULL means dont store)
    MaxEntryLen [in] Maximum key buffer size
    szString [out] Place to store the value of 'key=value' entry (NULL means dont store)
    MaxStringLen [in] Maximum value buffer size
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NO_MORE_DATA_pr09: no more Entrys in this section
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigNextEntry (ConfigHandle_tpr09 hConfig, 
			  char *szEntry, 
			  const int MaxEntryLen, 
			  char *szString, 
			  const int MaxStringLen, 
			  tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigCloseSection ()

  description:  Closes the registry section opened by pr09ConfigOpenSection ()
                
    Close the registry. This invalidates the given handle.
    Subsequent calls to pr09ConfigNextEntry() must fail.
  
  arguments:
    hConfig [in] Handle of registry file
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigCloseSection (ConfigHandle_tpr09 hConfig, 
		     tsp00_ErrText ErrText);

#ifdef __cplusplus
}                                    /* End of extern "C" { */
#endif  /* __cplusplus */
#endif /* __VPR09_CONFIG__ */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/pr/vpr09Config.h <==
/*!================================================================

  module:       vpr09Config.h

 -------------------------------------------------------------------

  responsible:  BurkhardD

  special area: Handling Configuration (ini) file entrys


  description : Handling of '.ini' files on UNIX and registry on NT.

     This module based on Registry for UNIX written by Joerg Mensing.
     It appends ven09.c functionalty to do the same on NT but use there 
     the registry instead of files.

  see also:

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#ifndef __VPR09_CONFIG_H__
#define __VPR09_CONFIG_H__

/*==================================================================*
 *  INCLUDES                                                        *
 *==================================================================*/

#include "hen09.h"

/*==================================================================*
 *  DECLARATIONS                                                    *
 *==================================================================*/

#ifdef __cplusplus
extern "C" {                         /* Assume C declarations for C++ */
#endif  /* __cplusplus */

#define KEY_SAP "SOFTWARE\\SAP"

typedef enum ConfigResult_tpr09 
{ 
  ERR_OK_epr09, 
  ERR_NOT_OK_epr09, 
  ERR_NO_MORE_DATA_epr09
} ConfigResult_tpr09;

#ifndef WIN32
typedef then09_ConfigHandle ConfigHandle_tpr09;
#else
typedef struct ConfigHandleStruct_tpr09 {
  HKEY hkResult;
  DWORD Index;
} ConfigHandleStruct_tpr09; 
typedef ConfigHandleStruct_tpr09 *ConfigHandle_tpr09;
#endif

/*==================================================================*
 *  EXTERNAL PROTOTYPES                                             *
 *==================================================================*/
/*!
  Function:     pr09SetDefaultKey ()

  description:  Overwrites the default key KEY SAP
  
 
  arguments:
    szKey [in] A pointer to a registry key name.

  return value: A pointer to the last key name.
 */
  char *pr09SetDefaultKey(char *szKey);

/*!
  Function:     pr09ConfigPutString ()

  description:  Writes or updates a Config Entry
  
   Inserts or replaces a string into the registry name 'szFile'
   to a position descripted by 'szSection'-name and 'szEntry'-name.
 
  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    szEntry [in] Given key of 'key=value' entry
    szString [in] Given value of 'key=value' entry
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigPutString (const char *szFile, 
		     const char *szSection,
		     const char *szEntry, 
		     const char *szString,
		     tsp00_ErrText ErrText);

ConfigResult_tpr09 pr09ConfigPutStringEx (const char *szFile, 
		     const char *szSection,
		     const char *szEntry, 
		     const char *szString,
		     tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigGetString ()

  description:  Reads the Stringvalue from the Config Entry
  
    Gives back a string from registry 'szFile' from the position descripted by
    'szSection' and 'szEntry'. It fails if either the file, the section or the
    entry does not exist.

  arguments:
    szFile [in] Name of registry file
    szSection [in] Given section to read from
    szEntry [in] Given key of 'key=value' entry
    szString [out] Place to store the value of 'key=value' entry
    MaxStringLen [in] Maximum value buffer size
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigGetString (const char * szFile, 
		     const char * szSection, 
		     const char * szEntry, 
		     char * szString, 
		     const int  MaxStringLen, 
		     tsp00_ErrText ErrText);

ConfigResult_tpr09 pr09ConfigGetStringEx (const char * szFile, 
		     const char * szSection, 
		     const char * szEntry, 
		     char * szString, 
		     const int  MaxStringLen, 
		     tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigRemoveEntry ()

  description:  Remove a Configentry from Registry
                
    Removes the entry specified by 'szSection' and 'szEntry' from config file 

  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    szEntry [in] Given key of 'key=value' entry
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */

ConfigResult_tpr09 pr09ConfigRemoveEntry (const char * szFile, 
		       const char * szSection,  
		       const char * szEntry,
		       tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigOpenSection ()

  description:  Open the registry 'szSection' for enumeration of the entrys
                
    Open the registery and position to the first entry of the given section.
    It is expected that a loop over 'pr09ConfigNextEntry()' is used to retrieve the
    entries.

    You must call pr09ConfigCloseSection after last usage of pr09ConfigNextEntry in all
    cases.
  
  arguments:
    szFile [in] Name of registry file
    szSection [in] Section to write into
    ErrText [out] Place for descriptive error message

  return value:
    <UL>
        handle  used in subsequent pr09ConfigNextEntry calls or NULL if an error occured
    </UL>
 */
ConfigHandle_tpr09 pr09ConfigOpenSection (const char *szFile, 
			    const char *szSection,
			    tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigNextEntry ()

  description:  Reads next entry from registry opened by pr09ConfigOpenSection ()
                
   Reads next 'szEntry' and 'szString' from section of config file opened by 
   pr09ConfigOpenSection (). If caller like, he can pass NULL pointer, which make
   it possible ie. just to count the entries of a section...

   Gives back 'ERR_NO_MORE_DATA_pr09' in return on end of section or end of file.
  
  arguments:
    hConfig [in] Handle of registry file
    szEntry [out] Place to store to key of 'key=value' entry (NULL means dont store)
    MaxEntryLen [in] Maximum key buffer size
    szString [out] Place to store the value of 'key=value' entry (NULL means dont store)
    MaxStringLen [in] Maximum value buffer size
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NO_MORE_DATA_pr09: no more Entrys in this section
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigNextEntry (ConfigHandle_tpr09 hConfig, 
			  char *szEntry, 
			  const int MaxEntryLen, 
			  char *szString, 
			  const int MaxStringLen, 
			  tsp00_ErrText ErrText);

/*!
  Function:     pr09ConfigCloseSection ()

  description:  Closes the registry section opened by pr09ConfigOpenSection ()
                
    Close the registry. This invalidates the given handle.
    Subsequent calls to pr09ConfigNextEntry() must fail.
  
  arguments:
    hConfig [in] Handle of registry file
    ErrText [out] Place for descriptive error message

  return value: ConfigResult_tpr09
    <UL>
        <LI>ERR_OK_epr090: ok
        <LI>ERR_NOT_OK_epr09: inspect ErrText
    </UL>
 */
ConfigResult_tpr09 pr09ConfigCloseSection (ConfigHandle_tpr09 hConfig, 
		     tsp00_ErrText ErrText);

#ifdef __cplusplus
}                                    /* End of extern "C" { */
#endif  /* __cplusplus */
#endif /* __VPR09_CONFIG__ */
